<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
        <template #operationBtn-checkBtn="{ data, row }">
          <PreviewBtnV2
            class="pro-table-operation-btn"
            :url="convertApi2FormUrlBySeparator(row.payFileUrl ?? '')"
            preview-btn-text="查看凭证"
          />
        </template>
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  AppContainer,
  useTable,
  PreviewBtnV2,
  ProTableV2,
  defineOperationBtns,
} from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import { convertApi2FormUrlBySeparator } from '@/utils';
import { FinanceTypeEnumText } from '@/constants';

defineOptions({
  name: 'ConsumeRecordView',
});

const column = [
  {
    id: '1',
    enCode: 'tradeTime',
    name: '消费时间',
  },
  {
    id: '2',
    enCode: 'tradeAmount',
    name: '消费金额',
  },
  {
    id: '3',
    enCode: 'payRemark',
    name: '消费类型',
  },
  {
    id: '4',
    enCode: 'financeType',
    name: '资金类型',
  },
];
const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'checkBtn',
      name: '查看凭证',
    },
  },
]);

const route = useRoute();
const router = useRouter();
const id = route.params.id as string;
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetParkBountyTradeDetailByIdInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        enterpriseId: id,
      };
      let res = await parkBountyApplyServices.getParkBountyTradeDetailList(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyWord: '',
      orderInput: [{ property: 'tradeTime', order: OrderInputType.Desc }],
    },
    columnsRenderProps: {
      tradeTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      tradeAmount: { type: 'money' },
      financeType: { type: 'enum', valueEnum: FinanceTypeEnumText },
    },
  }
);

onMounted(async () => {
  await getList();
  state.loading = false;
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
